@@ -1,6 +1,7 @@
 package Log::Dispatch::Email;
 
 use strict;
+use warnings;
 
 use Log::Dispatch::Output;
 
@@ -9,11 +10,10 @@ use base qw( Log::Dispatch::Output );
 use Params::Validate qw(validate SCALAR ARRAYREF BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
-use vars qw[ $VERSION ];
+our $VERSION = '1.19';
 
-$VERSION = '1.19';
-
-1;
+# need to untaint this value
+my ($program) = $0 =~ /(.+)/;
 
 sub new
 {
@@ -21,13 +21,13 @@ sub new
     my $class = ref $proto || $proto;
 
     my %p = validate( @_, { subject  => { type => SCALAR,
-					  default => "$0: log email" },
-			    to       => { type => SCALAR | ARRAYREF },
-			    from     => { type => SCALAR,
-					  optional => 1 },
-			    buffered => { type => BOOLEAN,
-					  default => 1 },
-			  } );
+                                          default => "$program: log email" },
+                            to       => { type => SCALAR | ARRAYREF },
+                            from     => { type => SCALAR,
+                                          optional => 1 },
+                            buffered => { type => BOOLEAN,
+                                          default => 1 },
+                          } );
 
     my $self = bless {}, $class;
 
@@ -52,11 +52,11 @@ sub log_message
 
     if ($self->{buffered})
     {
-	push @{ $self->{buffer} }, $p{message};
+        push @{ $self->{buffer} }, $p{message};
     }
     else
     {
-	$self->send_email(@_);
+        $self->send_email(@_);
     }
 }
 
@@ -74,9 +74,9 @@ sub flush
 
     if ($self->{buffered} && @{ $self->{buffer} })
     {
-	my $message = join '', @{ $self->{buffer} };
+        my $message = join '', @{ $self->{buffer} };
 
-	$self->send_email( message => $message );
+        $self->send_email( message => $message );
         $self->{buffer} = [];
     }
 }
@@ -88,6 +88,9 @@ sub DESTROY
     $self->flush;
 }
 
+
+1;
+
 __END__
 
 =head1 NAME
